@@ -1,7 +1,5 @@
 package WWW::EZTV::Episode;
-{
-  $WWW::EZTV::Episode::VERSION = '0.05';
-}
+$WWW::EZTV::Episode::VERSION = '0.06';
 use Moose;
 with 'WWW::EZTV::UA';
 
@@ -53,19 +51,19 @@ sub _parse {
         ((?<quality>\d+p)\s+)?
         (?<team>.*?)
       )
-      (?: 
+      (?:
         \s+
-        \((?<size> 
-          \d+ 
+        \((?<size>
+          \d+
           [^\)]+
-        )\) 
+        )\)
       )?
     \s*$/xi;
 
     return {
         name    => $+{name} || $title,
         chapter => $+{chapter},
-        number  => $+{number} +0,
+        number  => ($+{number}||0) +0,
         season  => ($+{season}||0) +0,
         total   => ($+{total}||0) +0,
         version => $+{version} || '',
@@ -77,9 +75,8 @@ sub _parse {
 
 1;
 
-
-
 __END__
+
 =pod
 
 =encoding UTF-8
@@ -90,7 +87,7 @@ WWW::EZTV::Episode - Show episode
 
 =head1 VERSION
 
-version 0.05
+version 0.06
 
 =head1 ATTRIBUTES
 
@@ -117,4 +114,3 @@ This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
